@@ -138,7 +138,7 @@ def doParseCommand(url):
                 elif tmpAry[1]=='update':
                     
                     # append gps info.
-                    ret = os.popen('python2.5 location.gps.py').read()
+                    ret = os.popen('python2.5 '+ROOT_PATH+'location.gps.py').read()
                     
                     if ret.find(',') > -1:
                         tmpParam = ret.split(',')
